<!-- This template is pure content, rendered by the API -->
<select class="form-select" name="data_path" required>
    <option value="" disabled selected>Select a data file...</option>
    {% for file in files %}
    <option value="{{ file.path }}">{{ file.name }}</option>
    {% endfor %}
</select>